@@ -10,16 +10,17 @@ import pandas as pd
 from econml.solutions.causal_analysis import CausalAnalysis
 
 from responsibleai._data_validations import validate_train_test_categories
-from responsibleai._internal.constants import (ManagerNames,
-                                               SerializationAttributes)
+from responsibleai._internal.constants import ManagerNames
 from responsibleai._managers.base_manager import BaseManager
+from responsibleai._tools.shared.state_directory_management import \
+    DirectoryManager
 from responsibleai._tools.causal.causal_config import CausalConfig
 from responsibleai._tools.causal.causal_constants import (DefaultParams,
                                                           ModelTypes,
                                                           ResultAttributes)
 from responsibleai._tools.causal.causal_result import CausalResult
 from responsibleai.exceptions import UserConfigValidationException
-from responsibleai.modelanalysis.constants import ModelTask
+from responsibleai.rai_insights.constants import ModelTask
 
 
 class CausalManager(BaseManager):
@@ -240,6 +241,8 @@ class CausalManager(BaseManager):
                 treatment_features[i], treatment_cost[i],
                 alpha, max_tree_depth, min_tree_leaf_samples)
             result.policies.append(policy)
+
+        result._validate_schema()
         self._results.append(result)
         return result
 
@@ -256,7 +259,7 @@ class CausalManager(BaseManager):
             message = str(e)
             expected = "increase the upper_bound_on_cat_expansion"
             clarification = (
-                " Increase the value {} in model_analysis.causal.add("
+                " Increase the value {} in rai_insights.causal.add("
                 "upper_bound_on_cat_expansion={})."
             ).format(max_cat_expansion, max_cat_expansion)
             if expected in message:
@@ -342,38 +345,39 @@ class CausalManager(BaseManager):
         causal_dir.mkdir(parents=True, exist_ok=True)
 
         # Save results to disk
-        results_path = causal_dir / SerializationAttributes.RESULTS_DIRECTORY
-        results_path.mkdir(parents=True, exist_ok=True)
         for result in self._results:
-            result_path = results_path / result.id
-            result.save(result_path)
+            directory_manager = DirectoryManager(parent_directory_path=path)
+            data_path = directory_manager.create_data_directory()
+            result.save(data_path)
 
     @staticmethod
-    def _load(path, model_analysis):
+    def _load(path, rai_insights):
         """Load the CausalManager from the given path.
 
         :param path: The directory path to load the CausalManager from.
         :type path: str
-        :param model_analysis: The loaded parent ModelAnalysis.
-        :type model_analysis: ModelAnalysis
+        :param rai_insights: The loaded parent RAIInsights.
+        :type rai_insights: RAIInsights
         :return: The CausalManager manager after loading.
         :rtype: CausalManager
         """
         inst = CausalManager.__new__(CausalManager)
 
-        causal_dir = Path(path)
-
         # Rehydrate results
-        results_path = causal_dir / SerializationAttributes.RESULTS_DIRECTORY
-        paths = results_path.resolve().glob('*')
-        inst.__dict__['_results'] = [CausalResult.load(p) for p in paths]
+        all_causal_dirs = DirectoryManager.list_sub_directories(path)
+        inst.__dict__['_results'] = []
+        for causal_dir in all_causal_dirs:
+            dm = DirectoryManager(parent_directory_path=path,
+                                  sub_directory_name=causal_dir)
+            causal_result = CausalResult.load(dm.get_data_directory())
+            inst.__dict__['_results'].append(causal_result)
 
         # Rehydrate model analysis data
-        inst.__dict__['_train'] = model_analysis.train
-        inst.__dict__['_test'] = model_analysis.test
-        inst.__dict__['_target_column'] = model_analysis.target_column
-        inst.__dict__['_task_type'] = model_analysis.task_type
+        inst.__dict__['_train'] = rai_insights.train
+        inst.__dict__['_test'] = rai_insights.test
+        inst.__dict__['_target_column'] = rai_insights.target_column
+        inst.__dict__['_task_type'] = rai_insights.task_type
         inst.__dict__['_categorical_features'] = \
-            model_analysis.categorical_features
+            rai_insights.categorical_features
 
         return inst
