@@ -4,8 +4,6 @@
 """Defines the Counterfactual Manager class."""
 import json
 import jsonschema
-import os
-import uuid
 
 import numpy as np
 from pathlib import Path
@@ -19,8 +17,11 @@ from responsibleai._interfaces import CounterfactualData
 from responsibleai._internal.constants import ManagerNames
 from responsibleai._managers.base_manager import BaseManager
 from responsibleai.exceptions import (DuplicateManagerConfigException,
+                                      SchemaErrorException,
                                       UserConfigValidationException)
-from responsibleai.modelanalysis.constants import ModelTask
+from responsibleai._tools.shared.state_directory_management import \
+    DirectoryManager
+from responsibleai.rai_insights.constants import ModelTask
 
 
 class CounterfactualConstants:
@@ -31,6 +32,80 @@ class CounterfactualConstants:
     RANDOM = 'random'
 
 
+class _CommonSchemaConstants:
+    LOCAL_IMPORTANCE = 'local_importance'
+    METADATA = 'metadata'
+    SUMMARY_IMPORTANCE = 'summary_importance'
+    VERSION = 'version'
+
+
+class _V1SchemaConstants:
+    CF_EXAMPLES_LIST = 'cf_examples_list'
+    LOCAL_IMPORTANCE = _CommonSchemaConstants.LOCAL_IMPORTANCE
+    METADATA = _CommonSchemaConstants.METADATA
+    SUMMARY_IMPORTANCE = _CommonSchemaConstants.SUMMARY_IMPORTANCE
+
+    ALL = [CF_EXAMPLES_LIST, LOCAL_IMPORTANCE, METADATA, SUMMARY_IMPORTANCE]
+
+
+class _V2SchemaConstants:
+    CFS_LIST = 'cfs_list'
+    DATA_INTERFACE = 'data_interface'
+    DESIRED_CLASS = 'desired_class'
+    DESIRED_RANGE = 'desired_range'
+    FEATURE_NAMES = 'feature_names'
+    FEATURE_NAMES_INCLUDING_TARGET = 'feature_names_including_target'
+    LOCAL_IMPORTANCE = _CommonSchemaConstants.LOCAL_IMPORTANCE
+    METADATA = _CommonSchemaConstants.METADATA
+    MODEL_TYPE = 'model_type'
+    SUMMARY_IMPORTANCE = _CommonSchemaConstants.SUMMARY_IMPORTANCE
+    TEST_DATA = 'test_data'
+
+    ALL = [CFS_LIST, DATA_INTERFACE, DESIRED_CLASS, DESIRED_RANGE,
+           FEATURE_NAMES, FEATURE_NAMES_INCLUDING_TARGET,
+           LOCAL_IMPORTANCE, METADATA, MODEL_TYPE,
+           SUMMARY_IMPORTANCE, TEST_DATA]
+
+
+class _SchemaVersions:
+    V1 = '1.0'
+    V2 = '2.0'
+
+    ALL_VERSIONS = [V1, V2]
+
+
+def _get_schema_version(counterfactuals_dict):
+    """
+    Get the version from the serialized version of the
+    counterfactual examples.
+
+    :param counterfactuals_dict: Serialized version of the
+                                 counterfactual example.
+    :type counterfactuals_dict: Dict
+    """
+    if _CommonSchemaConstants.METADATA not in counterfactuals_dict:
+        raise SchemaErrorException(
+            "No metadata field found in serialized counterfactual output"
+        )
+
+    metadata = counterfactuals_dict[_CommonSchemaConstants.METADATA]
+    if _CommonSchemaConstants.VERSION not in metadata:
+        raise SchemaErrorException(
+            "No version field found in serialized counterfactual output"
+        )
+
+    version = metadata[_CommonSchemaConstants.VERSION]
+    if version not in _SchemaVersions.ALL_VERSIONS:
+        raise SchemaErrorException(
+            "Schema version {0} not supported."
+            "Support versions are {1}".format(
+                version, ','.join(_SchemaVersions.ALL_VERSIONS)
+            )
+        )
+
+    return version
+
+
 class CounterfactualConfig(BaseConfig):
     METHOD = 'method'
     CONTINUOUS_FEATURES = 'continuous_features'
@@ -46,6 +121,9 @@ class CounterfactualConfig(BaseConfig):
     HAS_COMPUTATION_FAILED = 'has_computation_failed'
     FAILURE_REASON = 'failure_reason'
 
+    CONFIG_FILE_NAME = 'config.json'
+    RESULT_FILE_NAME = 'result.json'
+
     def __init__(self, method, continuous_features, total_CFs,
                  desired_class=CounterfactualConstants.OPPOSITE,
                  desired_range=None, permitted_range=None,
@@ -95,7 +173,38 @@ class CounterfactualConfig(BaseConfig):
             CounterfactualConfig.DESIRED_CLASS: self.desired_class,
             CounterfactualConfig.PERMITTED_RANGE: self.permitted_range,
             CounterfactualConfig.FEATURES_TO_VARY: self.features_to_vary,
-            CounterfactualConfig.FEATURE_IMPORTANCE: self.feature_importance}
+            CounterfactualConfig.FEATURE_IMPORTANCE: self.feature_importance
+        }
+
+    def save_config(self, config_directory_path):
+        config_file_path = (config_directory_path /
+                            CounterfactualConfig.CONFIG_FILE_NAME)
+        with open(config_file_path, 'w') as config_file:
+            json.dump(
+                self.get_config_as_dict(), config_file)
+
+    @staticmethod
+    def load_config(config_directory_path):
+        config_path = (config_directory_path /
+                       CounterfactualConfig.CONFIG_FILE_NAME)
+        with open(config_path, 'r') as config_file:
+            cf_config = json.load(config_file)
+
+        counterfactual_config = CounterfactualConfig(
+            method=cf_config[CounterfactualConfig.METHOD],
+            continuous_features=cf_config[
+                CounterfactualConfig.CONTINUOUS_FEATURES],
+            total_CFs=cf_config[CounterfactualConfig.TOTAL_CFS],
+            desired_class=cf_config[CounterfactualConfig.DESIRED_CLASS],
+            desired_range=cf_config[CounterfactualConfig.DESIRED_RANGE],
+            permitted_range=cf_config[
+                CounterfactualConfig.PERMITTED_RANGE],
+            features_to_vary=cf_config[
+                CounterfactualConfig.FEATURES_TO_VARY],
+            feature_importance=cf_config[
+                CounterfactualConfig.FEATURE_IMPORTANCE])
+
+        return counterfactual_config
 
     def get_result(self):
         """Returns the dictionary representation of result of the computation
@@ -119,6 +228,90 @@ class CounterfactualConfig(BaseConfig):
 
         return result
 
+    def save_result(self, data_directory_path):
+        cf_result = self.get_result()
+        if cf_result[CounterfactualConfig.COUNTERFACTUAL_OBJ] is not None:
+            counterfactuals_dict = json.loads(
+                cf_result[CounterfactualConfig.COUNTERFACTUAL_OBJ]
+            )
+
+            schema_version = _get_schema_version(counterfactuals_dict)
+            if schema_version == _SchemaVersions.V1:
+                cf_schema_keys = _V1SchemaConstants.ALL
+            else:
+                cf_schema_keys = _V2SchemaConstants.ALL
+
+            for counterfactual_examples_key in cf_schema_keys:
+                file_path = (data_directory_path /
+                             (counterfactual_examples_key + '.json'))
+                with open(file_path, 'w') as file_path:
+                    json.dump(
+                        counterfactuals_dict[counterfactual_examples_key],
+                        file_path)
+
+        file_path = (data_directory_path /
+                     (CounterfactualConfig.HAS_COMPUTATION_FAILED + '.json'))
+        with open(file_path, 'w') as file_path:
+            json.dump(
+                cf_result[CounterfactualConfig.HAS_COMPUTATION_FAILED],
+                file_path)
+
+        file_path = (data_directory_path /
+                     (CounterfactualConfig.FAILURE_REASON + '.json'))
+        with open(file_path, 'w') as file_path:
+            json.dump(
+                cf_result[CounterfactualConfig.FAILURE_REASON],
+                file_path)
+
+        file_path = (data_directory_path /
+                     (CounterfactualConfig.IS_COMPUTED + '.json'))
+        with open(file_path, 'w') as file_path:
+            json.dump(
+                cf_result[CounterfactualConfig.IS_COMPUTED],
+                file_path)
+
+    def load_result(self, data_directory_path):
+        metadata_file_path = (data_directory_path /
+                              (_CommonSchemaConstants.METADATA + '.json'))
+
+        if metadata_file_path.exists():
+            with open(metadata_file_path, 'r') as result_file:
+                metadata = json.load(result_file)
+
+            if metadata['version'] == _SchemaVersions.V1:
+                cf_schema_keys = _V1SchemaConstants.ALL
+            else:
+                cf_schema_keys = _V2SchemaConstants.ALL
+
+            counterfactual_examples_dict = {}
+            for counterfactual_examples_key in cf_schema_keys:
+                result_path = (data_directory_path /
+                               (counterfactual_examples_key + '.json'))
+                with open(result_path, 'r') as result_file:
+                    counterfactual_examples_dict[
+                        counterfactual_examples_key] = json.load(result_file)
+
+            counterfactuals_json_str = json.dumps(counterfactual_examples_dict)
+            self.counterfactual_obj = \
+                CounterfactualExplanations.from_json(counterfactuals_json_str)
+        else:
+            self.counterfactual_obj = None
+
+        result_path = (data_directory_path /
+                       (CounterfactualConfig.HAS_COMPUTATION_FAILED + '.json'))
+        with open(result_path, 'r') as result_file:
+            self.has_computation_failed = json.load(result_file)
+
+        result_path = (data_directory_path /
+                       (CounterfactualConfig.FAILURE_REASON + '.json'))
+        with open(result_path, 'r') as result_file:
+            self.failure_reason = json.load(result_file)
+
+        result_path = (data_directory_path /
+                       (CounterfactualConfig.IS_COMPUTED + '.json'))
+        with open(result_path, 'r') as result_file:
+            self.is_computed = json.load(result_file)
+
 
 class CounterfactualManager(BaseManager):
     _TRAIN = '_train'
@@ -128,8 +321,6 @@ class CounterfactualManager(BaseManager):
     _TASK_TYPE = '_task_type'
     _CATEGORICAL_FEATURES = '_categorical_features'
     _COUNTERFACTUAL_CONFIG_LIST = '_counterfactual_config_list'
-    CONFIG_FILE_NAME = 'config.json'
-    RESULT_FILE_NAME = 'result.json'
 
     def __init__(self, model, train, test, target_column, task_type,
                  categorical_features):
@@ -336,7 +527,7 @@ class CounterfactualManager(BaseManager):
                                 permitted_range=cf_config.permitted_range)
 
                     # Validate the serialized output against schema
-                    schema = self._get_counterfactual_schema(
+                    schema = CounterfactualManager._get_counterfactual_schema(
                         version=counterfactual_obj.metadata['version'])
                     jsonschema.validate(
                         json.loads(counterfactual_obj.to_json()), schema)
@@ -373,7 +564,8 @@ class CounterfactualManager(BaseManager):
                         counterfactual_config.failure_reason)
             return failure_reason_list
 
-    def _get_counterfactual_schema(self, version):
+    @staticmethod
+    def _get_counterfactual_schema(version):
         """Get the schema for validating the counterfactual examples output."""
         schema_directory = (Path(__file__).parent.parent / '_tools' /
                             'counterfactual' / 'dashboard_schemas')
@@ -426,91 +618,65 @@ class CounterfactualManager(BaseManager):
         counterfactual_dir = Path(path)
         counterfactual_dir.mkdir(parents=True, exist_ok=True)
         for counterfactual_config in self._counterfactual_config_list:
-            counterfactual_state_dir = Path(path) / str(uuid.uuid4())
-            counterfactual_state_dir.mkdir(parents=True, exist_ok=True)
+            directory_manager = DirectoryManager(parent_directory_path=path)
 
-            config_path = (counterfactual_state_dir /
-                           CounterfactualManager.CONFIG_FILE_NAME)
-            with open(config_path, 'w') as config_file:
-                json.dump(
-                    counterfactual_config.get_config_as_dict(),
-                    config_file)
+            counterfactual_config.save_config(
+                directory_manager.create_config_directory()
+            )
 
-            result_path = (counterfactual_state_dir /
-                           CounterfactualManager.RESULT_FILE_NAME)
-            with open(result_path, 'w') as result_file:
-                json.dump(
-                    counterfactual_config.get_result(),
-                    result_file)
+            counterfactual_config.save_result(
+                directory_manager.create_data_directory()
+            )
 
     @staticmethod
-    def _load(path, model_analysis):
+    def _load(path, rai_insights):
         """Load the CounterfactualManager from the given path.
 
         :param path: The directory path to load the CounterfactualManager from.
         :type path: str
-        :param model_analysis: The loaded parent ModelAnalysis.
-        :type model_analysis: ModelAnalysis
+        :param rai_insights: The loaded parent RAIInsights.
+        :type rai_insights: RAIInsights
         :return: The CounterfactualManager manager after loading.
         :rtype: CounterfactualManager
         """
         inst = CounterfactualManager.__new__(CounterfactualManager)
-        counterfactual_dir = Path(path)
 
         # Rehydrate model analysis data
-        inst.__dict__[CounterfactualManager._MODEL] = model_analysis.model
-        inst.__dict__[CounterfactualManager._TRAIN] = model_analysis.train
-        inst.__dict__[CounterfactualManager._TEST] = model_analysis.test
+        inst.__dict__[CounterfactualManager._MODEL] = rai_insights.model
+        inst.__dict__[CounterfactualManager._TRAIN] = rai_insights.train
+        inst.__dict__[CounterfactualManager._TEST] = rai_insights.test
         inst.__dict__[CounterfactualManager._TARGET_COLUMN] = \
-            model_analysis.target_column
+            rai_insights.target_column
         inst.__dict__[CounterfactualManager._TASK_TYPE] = \
-            model_analysis.task_type
+            rai_insights.task_type
         inst.__dict__[CounterfactualManager._CATEGORICAL_FEATURES] = \
-            model_analysis.categorical_features
+            rai_insights.categorical_features
 
         inst.__dict__[CounterfactualManager._COUNTERFACTUAL_CONFIG_LIST] = []
-        all_cf_dirs = os.listdir(counterfactual_dir)
+
+        all_cf_dirs = DirectoryManager.list_sub_directories(path)
         for counterfactual_config_dir in all_cf_dirs:
-            config_path = (Path(path) /
-                           counterfactual_config_dir /
-                           CounterfactualManager.CONFIG_FILE_NAME)
+            directory_manager = DirectoryManager(
+                parent_directory_path=path,
+                sub_directory_name=counterfactual_config_dir)
 
-            with open(config_path, 'r') as config_file:
-                cf_config = json.load(config_file)
+            counterfactual_config = CounterfactualConfig.load_config(
+                directory_manager.get_config_directory()
+            )
 
-            counterfactual_config = CounterfactualConfig(
-                method=cf_config[CounterfactualConfig.METHOD],
-                continuous_features=cf_config[
-                    CounterfactualConfig.CONTINUOUS_FEATURES],
-                total_CFs=cf_config[CounterfactualConfig.TOTAL_CFS],
-                desired_class=cf_config[CounterfactualConfig.DESIRED_CLASS],
-                desired_range=cf_config[CounterfactualConfig.DESIRED_RANGE],
-                permitted_range=cf_config[
-                    CounterfactualConfig.PERMITTED_RANGE],
-                features_to_vary=cf_config[
-                    CounterfactualConfig.FEATURES_TO_VARY],
-                feature_importance=cf_config[
-                    CounterfactualConfig.FEATURE_IMPORTANCE])
+            counterfactual_config.load_result(
+                directory_manager.get_data_directory()
+            )
 
-            result_path = (Path(path) /
-                           counterfactual_config_dir /
-                           CounterfactualManager.RESULT_FILE_NAME)
-
-            with open(result_path, 'r') as result_file:
-                cf_result = json.load(result_file)
-
-            if cf_result[CounterfactualConfig.COUNTERFACTUAL_OBJ] is not None:
-                counterfactual_config.counterfactual_obj = \
-                    CounterfactualExplanations.from_json(
-                        cf_result[CounterfactualConfig.COUNTERFACTUAL_OBJ])
-            else:
-                counterfactual_config.counterfactual_obj = None
-            counterfactual_config.has_computation_failed = \
-                cf_result[CounterfactualConfig.HAS_COMPUTATION_FAILED]
-            counterfactual_config.failure_reason = cf_result[
-                CounterfactualConfig.FAILURE_REASON]
-            counterfactual_config.is_computed = cf_result[
-                CounterfactualConfig.IS_COMPUTED]
+            if counterfactual_config.counterfactual_obj is not None:
+                # Validate the serialized output against schema
+                schema = CounterfactualManager._get_counterfactual_schema(
+                    version=counterfactual_config.counterfactual_obj.metadata[
+                        'version'])
+                jsonschema.validate(
+                    json.loads(
+                        counterfactual_config.counterfactual_obj.to_json()),
+                    schema)
 
             inst.__dict__[
                 CounterfactualManager._COUNTERFACTUAL_CONFIG_LIST].append(
