@@ -10,6 +10,7 @@ import numpy as np
 import os
 import pandas as pd
 import pytest
+from uuid import UUID
 
 from responsibleai import ModelAnalysis, ModelTask
 from responsibleai._internal.constants import ManagerNames
@@ -266,29 +267,31 @@ def validate_state_directory(path, manager_type):
     assert manager_type in all_dirs
     all_component_paths = os.listdir(path / manager_type)
     for component_path in all_component_paths:
-        # TODO: Add code to check if the component_path is GUID
+        # Test if the component directory has UUID structure
+        UUID(component_path, version=4)
+
         dm = DirectoryManager(path / manager_type, component_path)
 
         config_path = dm.get_config_directory()
         data_path = dm.get_data_directory()
-        explainer_path = dm.get_explainer_directory()
+        generators_path = dm.get_generators_directory()
 
         if manager_type == ManagerNames.EXPLAINER:
             assert not config_path.exists()
             assert data_path.exists()
-            assert not explainer_path.exists()
+            assert not generators_path.exists()
         elif manager_type == ManagerNames.COUNTERFACTUAL:
             assert config_path.exists()
             assert data_path.exists()
-            assert not explainer_path.exists()
+            assert not generators_path.exists()
         elif manager_type == ManagerNames.ERROR_ANALYSIS:
             assert config_path.exists()
             assert data_path.exists()
-            assert not explainer_path.exists()
+            assert not generators_path.exists()
         elif manager_type == ManagerNames.CAUSAL:
             assert not config_path.exists()
             assert data_path.exists()
-            assert not explainer_path.exists()
+            assert not generators_path.exists()
 
 
 def validate_model_analysis(
